Heatshield: Sun Shades for Cars, Trucks, and other Automobiles
Description: We sell windshield sun shades for cars, trucks, and vans. Heatshield protects against heat damage, and keeps the inside of parked cars cooler.

Internet Explorer users: There have been issues during checkout. Please use an alternative browser.

Call us: (408)738-3959
or toll-free (U.S. & Canada Only):
(800)777-6405

### New Gold Series Heatshields!

### Sun shades, windshield covers, sun reflectors & sun shields

#### They go by many names...

But our HeatShield is the original...they all refer to the same product: that thing you put above the dashboard of your car to block the sun and keep your car cool. Why choose our product? See below. But don't take our word for it! Read what others have to say!

### There are plenty of reasons to get a Heatshield for your car:

- stay cool
- custom-fit
- no fasteners
- durable

#### 25° F cooler on average.

The reflective material in our HeatShield sun shades is responsible for dramatic temperature differences in cars parked in the sun. We’ve measured a temperature difference of as much as 40˚ F (25˚ C.), but you will feel an average temperature reduction in your car of about 25˚ F (11˚ C).

#### Fits like a glove.

We’re serious about accuracy. Our computer-driven cutting machines are capable of producing precise HeatShields for virtually every car, truck, and van. Sometimes our Heatshields are designed to overlap the windshield frame to maximize coverage, or to allow the sun visors to have more material to hold on to.

#### No fasteners. No fuss.

Our front windshield Heatshields are designed to be supported with sun visors alone. No Velcro, no suction cups*, or anything else!
* our top, side, and rear window heatshields have 4-5 suction cups

#### Strong and Simple.

HeatShield is stiff enough to be supported by the sunvisors alone, but it is flexible enough to be bent around the rearview mirror. Unroll across dash, lift HeatShield and drop sunvisors. For storage, roll up and secure with special Velcro strap.

### Check out our gallery! (Click an image to enlarge):